@@ -5,6 +5,7 @@ Wrapper classes for API models. Most of these are thin wrappers over lxml
 objectified versions of API responses.
 """
 
+import datetime
 import lxml.etree
 from openprovider.util import camel_to_snake, snake_to_camel
 
@@ -39,7 +40,7 @@ class Model(object):
             attr = snake_to_camel(attr)
 
         if attr in self.__dict__:
-            # Check ourselves first no avoid infinite loops
+            # Check ourselves first to avoid infinite loops
             return getattr(self, attr)
 
         try:
@@ -66,7 +67,7 @@ class Model(object):
         return "<%s.%s: %s>" % (type(self).__module__, type(self).__name__, self)
 
     def __str__(self):
-        return lxml.etree.tostring(self._obj)
+        return str(lxml.etree.tostring(self._obj)) if self._obj else 'Empty model'
 
 
 def submodel(klass, key):
@@ -132,6 +133,47 @@ class Domain(Model):
         return "%s.%s" % (self.name, self.extension)
 
 
+class RegistryDetails(Model):
+    """
+    A container for a messages from the registry
+
+    messages
+        A list of messages
+    """
+
+    @property
+    def messages(self):
+        try:
+            return [RegistryMessage(item) for item in self.array[0].item]
+        except AttributeError:
+            return []
+
+
+class RegistryMessage(Model):
+    """
+    A message from the registry
+
+    date
+        A datetime object of the message
+    message
+        The actual message
+    """
+
+    @property
+    def date(self):
+        date = None
+        try:
+            date = self._attrs['date']
+        except KeyError:
+            if self._obj is not None:
+                try:
+                    date = self._obj['date']
+                except (AttributeError, KeyError):
+                    pass
+
+        return datetime.datetime.strptime(str(date), '%Y-%m-%d %H:%M:%S') if date else None
+
+
 class DomainDetails(Model):
     """
 
@@ -139,6 +181,7 @@ class DomainDetails(Model):
     """
 
     domain = submodel(Domain, "domain")
+    registry_details = submodel(RegistryDetails, "registryDetails")
 
     def __str__(self):
         return str(self.domain)
