@@ -163,6 +163,30 @@ class DomainModule(common.Module):
         response = self.request(request)
         return response.as_model(Model)
 
+    def trade_domain_request(self, domain, period, owner_handle, admin_handle, tech_handle,
+            billing_handle=None, reseller_handle=None, auth_code=None, ns_group=None,
+            ns_template_name=None, name_servers=None, use_domicile=None, promo_code=None,
+            dnssec_keys=None):
+
+        request = E.tradeDomainRequest(
+                _domain(domain),
+                E.period(period),
+                E.ownerHandle(owner_handle),
+                E.adminHandle(admin_handle),
+                E.techHandle(tech_handle),
+                OE('billingHandle', billing_handle),
+                OE('resellerHandle', reseller_handle),
+                OE('authCode', auth_code),
+                OE('nsGroup', ns_group),
+                OE('nsTemplateName', ns_template_name),
+                OE('nameServers', name_servers, transform=_nameservers),
+                OE('useDomicile', use_domicile, transform=int),
+                OE('promoCode', promo_code),
+                OE('dnssecKeys', dnssec_keys, transform=_dnssec_keys),
+        )
+        response = self.request(request)
+        return response.as_model(Model)
+
     def search_domain_request(self, limit=None, offset=None, extension=None,
             domain_name_pattern=None, contact_handle=None, ns_group_pattern=None, status=None,
             with_addition_data=None):
@@ -179,3 +203,38 @@ class DomainModule(common.Module):
         )
         response = self.request(request)
         return response.as_models(DomainDetails)
+
+    def renew_domain_request(self, domain, period):
+        request = E.renewDomainRequest(
+                _domain(domain),
+                E.period(period),
+        )
+        response = self.request(request)
+        return response.as_model(Model)
+
+    def request_auth_code_domain_request(self, domain, auth_code_type=None):
+        request = E.requestAuthCodeDomainRequest(
+                _domain(domain),
+                OE('authCodeType', auth_code_type),
+        )
+        response = self.request(request)
+        return response.as_model(Model)
+
+    def reset_auth_code_domain_request(self, domain):
+        request = E.resetAuthCodeDomainRequest(_domain(domain))
+        response = self.request(request)
+        return response.as_model(Model)
+
+    def approve_transfer_domain_request(self, domain, approve, registrar_tag=None):
+        request = E.approveTransferDomainRequest(
+                _domain(domain),
+                E.approve(int(approve)),
+                OE('registrarTag', registrar_tag),
+        )
+        response = self.request(request)
+        return response.as_model(Model)
+
+    def restore_domain_request(self, domain):
+        request = E.restoreDomainRequest(_domain(domain))
+        response = self.request(request)
+        return response.as_model(Model)
